@@ -49,7 +49,7 @@ class ChecksOdooModule:
     def _is_installable(self):
         return self.manifest_dict and self.manifest_dict.get("installable", True)
 
-    def _assets2filenames(self):
+    def _glob_expr2filenames(self, data_section):
         """Support new way of odoo to add assets
         e.g. odoo/addons/spreadsheet_dashboard/__manifest__.py
         "assets": {
@@ -61,10 +61,19 @@ class ChecksOdooModule:
         Only if the module is the same
         """
         fnames = []
-        for fname_glob_list in (self.manifest_dict.get("assets") or {}).values():
+        data_section_value = self.manifest_dict.get(data_section)
+        if isinstance(data_section_value, dict):
+            fname_glob_lists = self.manifest_dict[data_section].values()
+        elif isinstance(data_section_value, list):
+            fname_glob_lists = [data_section_value]
+        else:
+            fname_glob_lists = []
+        for fname_glob_list in fname_glob_lists:
             for fname_glob in fname_glob_list:
                 if not isinstance(fname_glob, str):
                     continue
+                if data_section == "qweb":
+                    fname_glob = os.path.join(os.path.basename(self.odoo_addon_path), fname_glob)
                 with utils.chdir(os.path.dirname(self.odoo_addon_path)):
                     for fname in glob.glob(fname_glob):
                         if not fname.startswith(self.odoo_addon_name):
@@ -76,8 +85,9 @@ class ChecksOdooModule:
     def _referenced_files_by_extension(self):
         ext_referenced_files = defaultdict(list)
         for data_section in DFTL_MANIFEST_DATA_KEYS + ["assets", "po"]:
-            if data_section == "assets":
-                manifest_fnames = self._assets2filenames()
+            if data_section in ["assets", "qweb"]:
+                # support glob expression
+                manifest_fnames = self._glob_expr2filenames(data_section)
             elif data_section == "po":
                 # The i18n[_extra]/*.po[t] files are not defined in the manifest
                 manifest_fnames = glob.glob(os.path.join(self.odoo_addon_path, "i18n*", "*.po")) + glob.glob(
@@ -159,7 +169,18 @@ def lookup_manifest_paths(filenames_or_modules):
     return odoo_module_files_changed
 
 
-def run(files_or_modules, enable=None, disable=None, no_verbose=False, no_exit=False):
+def run(files_or_modules, enable=None, disable=None, no_verbose=False, no_exit=False, list_msgs=False):
+    if list_msgs:
+        _, checks_docstring = utils.get_checks_docstring(
+            [ChecksOdooModule, checks_odoo_module_csv.ChecksOdooModuleCSV, checks_odoo_module_xml.ChecksOdooModuleXML]
+        )
+        if not no_verbose:
+            print("Emittable messages with the current interpreter:", end="")
+            print(checks_docstring)
+        if no_exit:
+            return checks_docstring
+        sys.exit(0)
+
     all_check_errors = []
     # TODO: Add unnitest to check files filtered from pre-commit by hook
     # Uncommet to check what files sent pre-commit
